@@ -2,8 +2,7 @@
 
 extern crate test;
 
-use sysinfo::get_current_pid;
-
+#[cfg(feature = "system")]
 #[bench]
 fn bench_new(b: &mut test::Bencher) {
     b.iter(|| {
@@ -11,6 +10,7 @@ fn bench_new(b: &mut test::Bencher) {
     });
 }
 
+#[cfg(feature = "system")]
 #[bench]
 fn bench_new_all(b: &mut test::Bencher) {
     b.iter(|| {
@@ -18,6 +18,7 @@ fn bench_new_all(b: &mut test::Bencher) {
     });
 }
 
+#[cfg(feature = "system")]
 #[bench]
 fn bench_refresh_all(b: &mut test::Bencher) {
     let mut s = sysinfo::System::new_all();
@@ -27,33 +28,36 @@ fn bench_refresh_all(b: &mut test::Bencher) {
     });
 }
 
+#[cfg(feature = "system")]
 #[bench]
 fn bench_refresh_processes(b: &mut test::Bencher) {
     let mut s = sysinfo::System::new();
 
-    s.refresh_processes(); // to load the whole processes list a first time.
+    s.refresh_processes(sysinfo::ProcessesToUpdate::All, true); // to load the whole processes list a first time.
     b.iter(move || {
-        s.refresh_processes();
+        s.refresh_processes(sysinfo::ProcessesToUpdate::All, true);
     });
 }
 
+#[cfg(feature = "system")]
 #[bench]
 fn bench_first_refresh_processes(b: &mut test::Bencher) {
     b.iter(move || {
         let mut s = sysinfo::System::new();
-        s.refresh_processes();
+        s.refresh_processes(sysinfo::ProcessesToUpdate::All, true);
     });
 }
 
+#[cfg(feature = "system")]
 #[bench]
 fn bench_refresh_process(b: &mut test::Bencher) {
     let mut s = sysinfo::System::new();
 
     s.refresh_all();
     // to be sure it'll exist for at least as long as we run
-    let pid = get_current_pid().expect("failed to get current pid");
+    let pid = sysinfo::get_current_pid().expect("failed to get current pid");
     b.iter(move || {
-        s.refresh_process(pid);
+        s.refresh_processes(sysinfo::ProcessesToUpdate::Some(&[pid]), true);
     });
 }
 
@@ -73,37 +77,21 @@ fn bench_refresh_disks(b: &mut test::Bencher) {
     let mut disks = sysinfo::Disks::new_with_refreshed_list();
 
     b.iter(move || {
-        disks.refresh();
-    });
-}
-
-#[bench]
-fn bench_refresh_disks_list(b: &mut test::Bencher) {
-    let mut disks = sysinfo::Disks::new_with_refreshed_list();
-
-    b.iter(move || {
-        disks.refresh_list();
+        disks.refresh(true);
     });
 }
 
+#[cfg(feature = "network")]
 #[bench]
 fn bench_refresh_networks(b: &mut test::Bencher) {
     let mut n = sysinfo::Networks::new_with_refreshed_list();
 
     b.iter(move || {
-        n.refresh();
-    });
-}
-
-#[bench]
-fn bench_refresh_networks_list(b: &mut test::Bencher) {
-    let mut n = sysinfo::Networks::new_with_refreshed_list();
-
-    b.iter(move || {
-        n.refresh_list();
+        n.refresh(true);
     });
 }
 
+#[cfg(feature = "system")]
 #[bench]
 fn bench_refresh_memory(b: &mut test::Bencher) {
     let mut s = sysinfo::System::new();
@@ -113,30 +101,24 @@ fn bench_refresh_memory(b: &mut test::Bencher) {
     });
 }
 
+#[cfg(feature = "system")]
 #[bench]
-fn bench_refresh_cpu(b: &mut test::Bencher) {
+fn bench_refresh_cpu_usage(b: &mut test::Bencher) {
     let mut s = sysinfo::System::new();
 
+    s.refresh_cpu_usage();
     b.iter(move || {
-        s.refresh_cpu();
+        s.refresh_cpu_usage();
     });
 }
 
+#[cfg(feature = "component")]
 #[bench]
 fn bench_refresh_components(b: &mut test::Bencher) {
     let mut c = sysinfo::Components::new_with_refreshed_list();
 
     b.iter(move || {
-        c.refresh();
-    });
-}
-
-#[bench]
-fn bench_refresh_components_list(b: &mut test::Bencher) {
-    let mut c = sysinfo::Components::new_with_refreshed_list();
-
-    b.iter(move || {
-        c.refresh_list();
+        c.refresh(false);
     });
 }
 
@@ -145,6 +127,6 @@ fn bench_refresh_users_list(b: &mut test::Bencher) {
     let mut users = sysinfo::Users::new_with_refreshed_list();
 
     b.iter(move || {
-        users.refresh_list();
+        users.refresh();
     });
 }
